from setuptools import setup, find_packages

setup(
    name="Biblioteca_libros",
    version="0.1",
    packages=find_packages(),
    install_requires=[],
    description="Una biblioteca para gestionar libros y autores",
    author="Cristhian Freire, Angelo Pila",
    author_email="cfreire.estud@ispade.edu.ec, apila.estud@ispade.edu.ec",
    url="https://github.com/cris9822/Biblioteca_libros",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)